# prettypretty

Prettypretty is a Python package to help build better terminal user interfaces.
For starters, prettypretty provides robust color manipulation and conversion,
including from and to terminal colors.

---

Copyright 2024 Robert Grimm. The code in this repository has been released as
open source under the [Apache 2.0](LICENSE).
